package VMOMI::HostOpaqueSwitchOpaqueSwitchState;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
